@@ -9,7 +9,7 @@ from functools import wraps
 from typing import List, Union, Callable, Tuple
 
 from .basic import Action, ActionList
-from ..mixin import Status, Configuration, InstanceRegistry
+from ..mixin import Status, Configuration, InstanceRegistry, DumpableList, make_iterable_serializable, make_mapping_serializable, serializable_cast
 
 
 logger = logging.getLogger(__name__)
@@ -341,22 +341,21 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
 
     def as_dict(self) -> dict:
         """dictionary of relevant information"""
+        dct = super(ConfiguredAction, self).as_dict()
         if self.next_action is not None:
             next_action_name = self.next_action.name
         else:
             next_action_name = None
-        out = {
+        dct.update({
             'name': self.name,
             'arguments': self.args,
             'keyword_arguments': self.kwargs,
-            'status_code': self.status_code,
-            'status': self.status_string,
             'next_action': next_action_name,
-        }
-        return out
+        })
+        return dct
 
 
-class ConfiguredActionList(ActionList):
+class ConfiguredActionList(ActionList, DumpableList):
     def __init__(self, *actions: Union[Action, ConfiguredAction]):
         """
         A manager for a list of Configured Actions.
@@ -376,6 +375,13 @@ class ConfiguredActionList(ActionList):
         else:
             return ConfiguredAction(action)
 
+    def as_list(self) -> list:
+        """returns a serializable list of relevant information about the configured actions"""
+        return [
+            action.as_dict()
+            for action in self._action_list
+        ]
+
 
 class ConfigurableInstance:
     methods_to_register: List[str] = []
@@ -646,14 +652,15 @@ class TrackedAction(InstanceRegistry, Configuration, Status):
 
     def as_dict(self) -> dict:
         """dictionary of relevant information"""
-        out = {
+        out = super(TrackedAction, self).as_dict()
+
+        out.update({
             'name': self.configuration.name,
-            'configuration': self.configuration.name,
-            'arguments': self.args,
-            'keyword_arguments': self.kwargs,
-            'status_code': self.status_code,
-            'status': self.status_string,
-        }
+            'configuration': self.configuration.as_dict(),
+            'arguments': make_iterable_serializable(*self.args),
+            'keyword_arguments': make_mapping_serializable(**self.kwargs),
+        })
+
         if self.time_started is not None:
             out['time_started'] = self.time_started
             out['timestamp'] = str(self.started_timestamp)
@@ -664,7 +671,7 @@ class TrackedAction(InstanceRegistry, Configuration, Status):
                 out['error_during_execution'] = True
                 out['error_details'] = str(self.error_details)
             else:  # if completed and no error, include the method return
-                out['action_return'] = self.action_return
+                out['action_return'] = serializable_cast(self.action_return)
                 out['condition_evaluation'] = self._condition_evaluation
         return out
 
@@ -795,7 +802,7 @@ class ThreadedTrackedAction(TrackedAction):
             self._thread.join()  # todo support timeout
 
 
-class TrackedActionList(ActionList):
+class TrackedActionList(ActionList, DumpableList):
     def __init__(self, *actions: Union[Action, ConfiguredAction, TrackedAction]):
         """
         A manager for a list of Tracked Actions.
@@ -813,3 +820,9 @@ class TrackedActionList(ActionList):
             return action
         else:
             return TrackedAction(action)
+
+    def as_list(self) -> list:
+        return [
+            action.as_dict()
+            for action in self._action_list
+        ]
