@@ -1,4 +1,7 @@
-class Status:
+from .serialization import DumpableState
+
+
+class Status(DumpableState):
     # dictionary of action states
     ACTION_STATES = {
         -1: 'ERROR',
@@ -26,3 +29,10 @@ class Status:
     def status(self) -> str:
         """status string for the Action"""
         return f'{self.status_code}: {self.status_string}'
+
+    def as_dict(self) -> dict:
+        """represents the status as a dictionary"""
+        return {
+            'status_code': self.status_code,
+            'status': self.status,
+        }
