@@ -9,7 +9,7 @@ import warnings
 import time
 
 from typing import Union, Callable, Iterable
-from .mixin import InstanceRegistry
+from .mixin import InstanceRegistry, DumpableState
 from .action import Action, ConfiguredAction, ConfiguredActionList
 from .sequencing import ExecutionSequence, ConfiguredSequence
 from .action.configured import ensure_triggered
@@ -17,7 +17,7 @@ from .action.configured import ensure_triggered
 logger = logging.getLogger(__name__)
 
 
-class TimePoint(InstanceRegistry):
+class TimePoint(InstanceRegistry, DumpableState):
     UUID_PREFIX = 'tp-'
 
     def __init__(self,
@@ -66,8 +66,9 @@ class TimePoint(InstanceRegistry):
         return self.UUID_PREFIX + self._uuid
 
     @property
-    def basic_dict(self) -> dict:
+    def _timepoint_basic_dict(self) -> dict:
         """basic dictionary for any TimePoint class or subclass"""
+        # todo update this when the dependency diamond is resolved
         return {
             'time_delta': self.time_delta,
             'uuid': self.uuid,
@@ -92,7 +93,7 @@ class TimePoint(InstanceRegistry):
 
     def as_dict(self) -> dict:
         """Returns a key: value representation of the instance"""
-        return self.basic_dict
+        return self._timepoint_basic_dict
 
     def sample_time_from_reference(self, reference_time: float):
         """
@@ -288,17 +289,7 @@ class ActionTimePoint(ExecutionSequence, TimePoint):
     def as_dict(self) -> dict:
         """Returns a key: value representation of the instance"""
         dct = super(ActionTimePoint, self).as_dict()
-        dct.update(self.basic_dict)
-        del dct['arguments']
-        del dct['keyword_arguments']
-        dct['triggered'] = self.triggered
-        if self.triggered is True:
-            actions = self.args
-        else:
-            actions = self.configuration.action_sequence
-        dct['actions'] = [
-            action.as_dict() for action in actions
-        ]
+        dct.update(self._timepoint_basic_dict)
         # todo decide how to include relative start times
         return dct
 
